@@ -267,9 +267,8 @@ class APIAdminSimulator(APIAdminContract):
         self._store = SimulatorDataStore(
             api_url or 'http://localhost:8001/apis/',
             data_struct_filter={
-                'inbound_dns': None,
-                'path': None,
-                'strip_path': False
+                'request_host': None,
+                'request_path': None
             })
         self._plugin_admins = {}
 
@@ -285,32 +284,30 @@ class APIAdminSimulator(APIAdminContract):
     def count(self):
         return self._store.count()
 
-    def add(self, upstream_url, name=None, inbound_dns=None, path=None, strip_path=False):
+    def add(self, upstream_url, name=None, request_host=None, request_path=None):
         assert upstream_url is not None
-        if not inbound_dns and not path:
-            raise ValueError('At least a \'inbound_dns\' or a \'path\' must be specified, '
-                             'At least a \'inbound_dns\' or a \'path\' must be specified')  # According to spec
+        if not request_host and not request_path:
+            raise ValueError('At least a \'request_host\' or a \'request_path\' must be specified, '
+                             'At least a \'request_host\' or a \'request_path\' must be specified')  # According to spec
 
         # ensure trailing slash
         upstream_url = ensure_trailing_slash(upstream_url)
 
         return self._store.create({
-            'name': name or inbound_dns,
-            'inbound_dns': inbound_dns,
-            'path': path,
+            'name': name or request_host,
+            'request_host': request_host,
+            'request_path': request_path,
             'upstream_url': upstream_url,
-            'strip_path': strip_path,
             'created_at': timestamp()
-        }, check_conflict_keys=('name', 'inbound_dns'))
+        }, check_conflict_keys=('name', 'request_host'))
 
-    def add_or_update(self, upstream_url, api_id=None, name=None, inbound_dns=None, path=None, strip_path=False,
+    def add_or_update(self, upstream_url, api_id=None, name=None, request_host=None, request_path=None,
                       preserve_host=False):
         data = {
-            'name': name or inbound_dns,
-            'inbound_dns': inbound_dns,
-            'path': path,
+            'name': name or request_host,
+            'request_host': request_host,
+            'request_path': request_path,
             'upstream_url': upstream_url,
-            'strip_path': strip_path
         }
 
         if api_id is not None:
@@ -330,7 +327,7 @@ class APIAdminSimulator(APIAdminContract):
         return self._store.retrieve(name_or_id, 'name')
 
     def list(self, size=100, offset=None, **filter_fields):
-        assert_dict_keys_in(filter_fields, ['id', 'name', 'inbound_dns', 'upstream_url'])
+        assert_dict_keys_in(filter_fields, ['id', 'name', 'request_host', 'upstream_url'])
         return self._store.list(size, offset, **filter_fields)
 
     def delete(self, name_or_id):
